# This file is generated by /root/worker/containers/00000blmksd/tmp/build/80754af9/numpy_and_dev_1530549925073/work/setup.py
# It contains system_info results at the time of building this package.
__all__ = ["get_info","show"]

lapack_opt_info={'libraries': ['openblas', 'openblas'], 'library_dirs': ['/opt/anaconda1anaconda2anaconda3/lib'], 'language': 'f77'}
openblas_lapack_info={'libraries': ['openblas', 'openblas'], 'library_dirs': ['/opt/anaconda1anaconda2anaconda3/lib'], 'language': 'f77'}
blas_mkl_info={}
openblas_info={'libraries': ['openblas', 'openblas'], 'library_dirs': ['/opt/anaconda1anaconda2anaconda3/lib'], 'language': 'f77'}
blas_opt_info={'libraries': ['openblas', 'openblas'], 'library_dirs': ['/opt/anaconda1anaconda2anaconda3/lib'], 'language': 'f77'}

def get_info(name):
    g = globals()
    return g.get(name, g.get(name + "_info", {}))

def show():
    for name,info_dict in globals().items():
        if name[0] == "_" or type(info_dict) is not type({}): continue
        print(name + ":")
        if not info_dict:
            print("  NOT AVAILABLE")
        for k,v in info_dict.items():
            v = str(v)
            if k == "sources" and len(v) > 200:
                v = v[:60] + " ...\n... " + v[-60:]
            print("    %s = %s" % (k,v))
    